library fluttertextfield;
import 'package:flutter/material.dart';
import 'GeneralFunctions.dart';
// ignore: must_be_immutable
class CommonTextField extends StatelessWidget {
  //TEXT FIELD HINT
  final String hint;

  //TEXT FIELD ICON PATH
  final String iconPath;

  //TEXT FIELD HINT COLOR
  Color hintColor = Color(0xff777777);

  //TEXT FIELD BELOW LINE COLOR
  Color lineColor = Color(0xffD1D1D1);

  //INIT TEXT FIELD
  final inputTextFieldValue;

  //INPUT TYPE FOR TEXT FIELD - NUMBER, PASSWORD, EMAIL, TEXT
  InputType textFieldInputType;

  //CONSTRUCTOR
  CommonTextField(this.hint, this.iconPath, this.inputTextFieldValue,
      [this.hintColor, this.lineColor, this.textFieldInputType]);

  //FOR FOCUS TO TEXT FIELD
  final FocusNode focus = new FocusNode();

  @override
  Widget build(BuildContext context) {
    return new Container(
      width: MediaQuery.of(context).size.width,
      margin: const EdgeInsets.only(left: 25.0, right: 25.0),
      alignment: Alignment.center,
      decoration: BoxDecoration(
        border: Border(
          bottom: BorderSide(
              color: lineColor, width: 0.5, style: BorderStyle.solid),
        ),
      ),
      child: new Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          new Padding(
            padding: EdgeInsets.only(top: 10.0, bottom: 10.0, right: 10.0),
            child: Image.asset(
              iconPath,
              height: 16,
            ),
          ),
          new Expanded(
            child: TextFormField(
              style: setFont(
                  FontWeight.normal, FontStyle.normal, 15),
              focusNode: focus,
              controller: inputTextFieldValue,
              textAlign: TextAlign.start,
              //TEXT FIELD TYPE PASSWORD or NOT, obscureText = true MEANS PASSWORD TYPE
              obscureText:
              ((GeneralFunctions.textFieldInputType(textFieldInputType) ==
                  TextInputType.visiblePassword)
                  ? true
                  : false),
              //SET KEYBOARD TYPE FOR - NUMBER, TEXT, EMAIL, ETC.
              keyboardType: getKeyboardType(),
              decoration: InputDecoration(
                border: InputBorder.none,
                hintText: hint,
                hintStyle: TextStyle(color: hintColor, fontSize: 15),
              ),
            ),
          ),
        ],
      ),
    );
  }

  //FUNCTION RETURNS TEXT FILED TO GET ALL PARAMETERS OF TEXT FILED
  TextEditingController getFieldValue() {
    return inputTextFieldValue;
  }

  getKeyboardType() {
    return GeneralFunctions.textFieldInputType(textFieldInputType);
  }

  static setFont(FontWeight weight,
      [FontStyle style = FontStyle.normal, double fontSize = 15]) {
    return TextStyle(
        fontFamily: AppFont.roboto,

        //FontWeight - normal OR bold
        fontWeight: FontWeight.normal,

        //FontStyle - normal OR italic
        fontStyle: style,

        //Text font size
        fontSize: fontSize);
  }
}
